@@ -1,12 +1,11 @@
 package Sah::Schema::negeven;
 
 our $DATE = '2016-07-18'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
-our $schema = ['int', {
+our $schema = ['negint', {
     summary => 'Negative even number',
     div_by => 2,
-    max => -1,
 }, {}];
 
 1;
@@ -24,7 +23,7 @@ Sah::Schema::negeven - Negative even number
 
 =head1 VERSION
 
-This document describes version 0.04 of Sah::Schema::negeven (from Perl distribution Sah-Schemas-Int), released on 2016-07-18.
+This document describes version 0.05 of Sah::Schema::negeven (from Perl distribution Sah-Schemas-Int), released on 2016-07-18.
 
 =head1 HOMEPAGE
 
