@@ -1,12 +1,11 @@
 package Sah::Schema::poseven;
 
 our $DATE = '2016-07-18'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
-our $schema = ['int', {
+our $schema = ['posint', {
     summary => 'Positive even number',
     div_by => 2,
-    min => 0,
 }, {}];
 
 1;
@@ -24,7 +23,7 @@ Sah::Schema::poseven - Positive even number
 
 =head1 VERSION
 
-This document describes version 0.04 of Sah::Schema::poseven (from Perl distribution Sah-Schemas-Int), released on 2016-07-18.
+This document describes version 0.05 of Sah::Schema::poseven (from Perl distribution Sah-Schemas-Int), released on 2016-07-18.
 
 =head1 HOMEPAGE
 
