@@ -1,13 +1,12 @@
 package Sah::Schema::posodd;
 
 our $DATE = '2016-07-18'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
-our $schema = ['int', {
+our $schema = ['posint', {
     summary => 'Positive odd number',
     div_by => 2,
     'div_by.op' => 'not',
-    min => 0,
 }, {}];
 
 1;
@@ -25,7 +24,7 @@ Sah::Schema::posodd - Positive odd number
 
 =head1 VERSION
 
-This document describes version 0.04 of Sah::Schema::posodd (from Perl distribution Sah-Schemas-Int), released on 2016-07-18.
+This document describes version 0.05 of Sah::Schema::posodd (from Perl distribution Sah-Schemas-Int), released on 2016-07-18.
 
 =head1 HOMEPAGE
 
